@@ -179,10 +179,10 @@ class MusicDatabaseHandlerTest(protocol.BaseTestCase):
         self.send_request("listall")
 
         self.assertInResponse("file: dummy:/a")
-        self.assertInResponse("directory: /dummy/foo")
-        self.assertInResponse("directory: /dummy/album")
-        self.assertInResponse("directory: /dummy/artist")
-        self.assertInResponse("directory: /dummy/pl")
+        self.assertInResponse("directory: dummy/foo")
+        self.assertInResponse("directory: dummy/album")
+        self.assertInResponse("directory: dummy/artist")
+        self.assertInResponse("directory: dummy/pl")
         self.assertInResponse("file: dummy:/foo/b")
         self.assertInResponse("OK")
 
@@ -203,7 +203,7 @@ class MusicDatabaseHandlerTest(protocol.BaseTestCase):
         self.send_request('listall "/dummy/foo"')
 
         self.assertNotInResponse("file: dummy:/a")
-        self.assertInResponse("directory: /dummy/foo")
+        self.assertInResponse("directory: dummy/foo")
         self.assertInResponse("file: dummy:/foo/b")
         self.assertInResponse("OK")
 
@@ -245,8 +245,8 @@ class MusicDatabaseHandlerTest(protocol.BaseTestCase):
         }
 
         self.send_request("listall")
-        self.assertInResponse("directory: /dummy/a")
-        self.assertInResponse("directory: /dummy/a [2]")
+        self.assertInResponse("directory: dummy/a")
+        self.assertInResponse("directory: dummy/a [2]")
 
     def test_listallinfo_without_uri(self):
         tracks = [
@@ -269,10 +269,10 @@ class MusicDatabaseHandlerTest(protocol.BaseTestCase):
 
         self.assertInResponse("file: dummy:/a")
         self.assertInResponse("Title: a")
-        self.assertInResponse("directory: /dummy/foo")
-        self.assertInResponse("directory: /dummy/album")
-        self.assertInResponse("directory: /dummy/artist")
-        self.assertInResponse("directory: /dummy/pl")
+        self.assertInResponse("directory: dummy/foo")
+        self.assertInResponse("directory: dummy/album")
+        self.assertInResponse("directory: dummy/artist")
+        self.assertInResponse("directory: dummy/pl")
         self.assertInResponse("file: dummy:/foo/b")
         self.assertInResponse("Title: b")
         self.assertInResponse("OK")
@@ -295,7 +295,7 @@ class MusicDatabaseHandlerTest(protocol.BaseTestCase):
 
         self.assertNotInResponse("file: dummy:/a")
         self.assertNotInResponse("Title: a")
-        self.assertInResponse("directory: /dummy/foo")
+        self.assertInResponse("directory: dummy/foo")
         self.assertInResponse("file: dummy:/foo/b")
         self.assertInResponse("Title: b")
         self.assertInResponse("OK")
@@ -338,8 +338,8 @@ class MusicDatabaseHandlerTest(protocol.BaseTestCase):
         }
 
         self.send_request("listallinfo")
-        self.assertInResponse("directory: /dummy/a")
-        self.assertInResponse("directory: /dummy/a [2]")
+        self.assertInResponse("directory: dummy/a")
+        self.assertInResponse("directory: dummy/a [2]")
 
     def test_listfiles(self):
         self.send_request("listfiles")
@@ -733,7 +733,13 @@ class MusicDatabaseListTest(protocol.BaseTestCase):
 
     def test_list_foo_returns_ack(self):
         self.send_request('list "foo"')
-        self.assertEqualResponse("ACK [2@0] {list} incorrect arguments")
+        self.assertEqualResponse("ACK [2@0] {list} Unknown tag type: foo")
+
+    def test_list_without_type_returns_ack(self):
+        self.send_request("list")
+        self.assertEqualResponse(
+            'ACK [2@0] {list} too few arguments for "list"'
+        )
 
     # Track title
 
@@ -741,6 +747,10 @@ class MusicDatabaseListTest(protocol.BaseTestCase):
         self.send_request('list "title"')
         self.assertInResponse("OK")
 
+    def test_list_title_by_title(self):
+        self.send_request('list "title" "title" "atitle"')
+        self.assertInResponse("OK")
+
     # Artist
 
     def test_list_artist_with_quotes(self):
@@ -763,7 +773,7 @@ class MusicDatabaseListTest(protocol.BaseTestCase):
 
     def test_list_artist_with_unknown_field_in_query_returns_ack(self):
         self.send_request('list "artist" "foo" "bar"')
-        self.assertEqualResponse("ACK [2@0] {list} not able to parse args")
+        self.assertEqualResponse("ACK [2@0] {list} Unknown filter type")
 
     def test_list_artist_by_artist(self):
         self.send_request('list "artist" "artist" "anartist"')
@@ -824,7 +834,7 @@ class MusicDatabaseListTest(protocol.BaseTestCase):
 
     def test_list_albumartist_with_unknown_field_in_query_returns_ack(self):
         self.send_request('list "albumartist" "foo" "bar"')
-        self.assertEqualResponse("ACK [2@0] {list} not able to parse args")
+        self.assertEqualResponse("ACK [2@0] {list} Unknown filter type")
 
     def test_list_albumartist_by_artist(self):
         self.send_request('list "albumartist" "artist" "anartist"')
@@ -890,7 +900,7 @@ class MusicDatabaseListTest(protocol.BaseTestCase):
 
     def test_list_composer_with_unknown_field_in_query_returns_ack(self):
         self.send_request('list "composer" "foo" "bar"')
-        self.assertEqualResponse("ACK [2@0] {list} not able to parse args")
+        self.assertEqualResponse("ACK [2@0] {list} Unknown filter type")
 
     def test_list_composer_by_artist(self):
         self.send_request('list "composer" "artist" "anartist"')
@@ -956,7 +966,7 @@ class MusicDatabaseListTest(protocol.BaseTestCase):
 
     def test_list_performer_with_unknown_field_in_query_returns_ack(self):
         self.send_request('list "performer" "foo" "bar"')
-        self.assertEqualResponse("ACK [2@0] {list} not able to parse args")
+        self.assertEqualResponse("ACK [2@0] {list} Unknown filter type")
 
     def test_list_performer_by_artist(self):
         self.send_request('list "performer" "artist" "anartist"')
